@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
-from zscalertools import zia
+#from zscalertools import zia
+import zscalertools
 import logging
 import yaml
 import unittest
@@ -14,7 +15,7 @@ stream.close()
 
 class TestSequenceFunctions(unittest.TestCase):
   def setUp(self):
-    self.api = zia.api(config['url'], config['username'], config['password'], config['cloud_api_key'])
+    self.api = zscalertools.zia.api(config['url'], config['username'], config['password'], config['cloud_api_key'])
     
   def test_login_logout(self):
     login = self.api.login()
@@ -34,10 +35,5 @@ class TestSequenceFunctions(unittest.TestCase):
         sub_location = self.api.get_sublocations(location['id'])
         self.assertTrue('id', sub_location)
 
-  def test_getUsers(self):
-    specialusers = self.api.get_users(group='WW_IT-SWG-Config-Z-App-Disable-On-VPN')
-    print(specialusers)
-
-
 if __name__ == "__main__":
   unittest.main()
\ No newline at end of file
